Crate penumbra_sdk_test_subscriber

Crate penumbra_sdk_test_subscriber 

A pretty tracing subscriber for use in test cases.

NB: this subscriber makes use of a test writer, that is compatible with cargo test’s output capturing.

Functions

set_tracing_subscriber
Installs a tracing subscriber to log events until the returned guard is dropped.
set_tracing_subscriber_with_env_filter
Install a tracing subscriber with a custom filter.