A pretty tracing subscriber for use in test cases.
NB: this subscriber makes use of a test writer, that is compatible with cargo test’s output
capturing.
Functions
- set_
tracing_ subscriber - Installs a tracing subscriber to log events until the returned guard is dropped.
- set_
tracing_ subscriber_ with_ env_ filter - Install a tracing subscriber with a custom filter.